@@ -1,5 +1,5 @@
 package App::cpanminus;
-our $VERSION = "0.99_33";
+our $VERSION = "0.999_01";
 
 =head1 NAME
 
@@ -8,11 +8,6 @@ App::cpanminus - get, unpack, build and install modules from CPAN
 =head1 SYNOPSIS
 
     cpanm Module
-    cpanm MIYAGAWA/Plack-1.0000.tar.gz
-    cpanm ~/mydists/MyCompany-Framework-1.0.tar.gz
-    cpanm http://example.com/MyModule-0.1.tar.gz
-    cpanm http://github.com/miyagawa/Tatsumaki/tarball/master
-    cpanm --interactive Task::Kensho
 
 Run C<cpanm -h> for more options.
 
@@ -20,9 +15,8 @@ Run C<cpanm -h> for more options.
 
 cpanminus is a script to get, unpack, build and install modules from CPAN.
 
-Why? It's dependency free, requires zero configuration, and stands alone -- but
-it's maintainable and extensible with plugins and friendly to shell scripting.
-When running, it requires only 10MB of RAM.
+Why? It's dependency free, requires zero configuration, and stands
+alone. When running, it requires only 10MB of RAM.
 
 =head1 INSTALLATION
 
@@ -85,22 +79,6 @@ Module::Build (core in 5.10) to install Build.PL based modules
 
 =back
 
-=head1 PLUGINS
-
-B<WARNING: plugin API is not stable so this feature is turned off by
-default for now. To enable plugins you have to be savvy enough to look
-at the build.log or read the source code to see how :)>
-
-The cpanminus core is a compact and simple 1000 lines of code (with some
-embedded utilities and documents) but can be extended by writing plugins.
-Plugins are flat perl scripts placed inside C<~/.cpanm/plugins>. You can copy
-(or symlink, if you're a developer) a plugin file to the directory to enable
-plugins.  Delete the file or symlink to disable it.
-
-See the C<plugins/> directory in the git repository
-L<http://github.com/miyagawa/cpanminus> for the list of available and
-sample plugins.
-
 =head1 QUESTIONS
 
 =head2 Another CPAN installer?
